.. toctree::
   :hidden:
   :maxdepth: 2


fabulist module
---------------

.. automodule:: fabulist.fabulist
    :members: Fabulist, _WordList
    :undoc-members:
    :show-inheritance:

..    :private-members:
